Test coverage report: multilingual_events.simple_translate

# multilingual_events.simple_translate: 4 total statements, 0.0% covered

Generated: Thu 2013-02-28 16:32 SGT

Source file: /Users/martin/Repos/django-multilingual-events/multilingual_events/simple_translate.py

Stats: 0 executed, 2 missed, 2 excluded, 5 ignored

1. `"""Registering translated models for the ``multilingual_events`` app."""`
2. `from simple_translation.translation_pool import translation_pool`
3. ``
4. `from . import models`
5. ``
6. ``
7. `translation_pool.register_translation(`
8. `models.EventCategory, models.EventCategoryTitle)`
9. `translation_pool.register_translation(models.Event, models.EventTitle)`